<?php
defined( 'ABSPATH' ) || die();
require_once STSSM_PLUGIN_DIR_PATH . 'includes/class-stssm-helper.php';

class STSSM_Setting {
	public static function add_action_links( $links ) {
		$links[] = '<a href="'. esc_url( admin_url( 'options-general.php?page=stssm_settings' ) ) .'">' . esc_html__( 'Settings', 'share-social-media' ) . '</a>';
		return $links;
	}

	public static function save_social_share_icons() {
		if ( ! current_user_can( 'manage_options' ) ) {
			die();
		}

		if ( ! isset( $_POST['save-social-share-icons'] ) || ! wp_verify_nonce( $_POST['save-social-share-icons'], 'save-social-share-icons' ) ) {
			die();
		}

		$sticky_icons_enable    = isset( $_POST['sticky_icons_enable'] ) ? (bool) $_POST['sticky_icons_enable'] : false;
		$sticky_icons_placement = isset( $_POST['sticky_icons_placement'] ) ? sanitize_text_field( $_POST['sticky_icons_placement'] ) : 'left';

		$all_pages_enable     = isset( $_POST['all_pages_enable'] ) ? (bool) $_POST['all_pages_enable'] : false;
		$pages_before_content = isset( $_POST['pages_before_content'] ) ? (bool) $_POST['pages_before_content'] : false;
		$pages_after_content  = isset( $_POST['pages_after_content'] ) ? (bool) $_POST['pages_after_content'] : false;

		$all_posts_enable     = isset( $_POST['all_posts_enable'] ) ? (bool) $_POST['all_posts_enable'] : false;
		$posts_before_content = isset( $_POST['posts_before_content'] ) ? (bool) $_POST['posts_before_content'] : false;
		$posts_after_content  = isset( $_POST['posts_after_content'] ) ? (bool) $_POST['posts_after_content'] : false;

		if ( ! in_array( $sticky_icons_placement, array_keys( STSSM_Helper::icons_placement_list_sticky() ) ) ) {
			$sticky_icons_placement = 'left';
		}

		update_option(
			'stssm_sticky_placement',
			array(
				'enable' => $sticky_icons_enable,
				'place'  => $sticky_icons_placement,
			),
			true
		);

		update_option(
			'stssm_pages_placement',
			array(
				'enable'         => $all_pages_enable,
				'after_content'  => $pages_after_content,
				'before_content' => $pages_before_content,
			),
			true
		);

		update_option(
			'stssm_posts_placement',
			array(
				'enable'         => $all_posts_enable,
				'after_content'  => $posts_after_content,
				'before_content' => $posts_before_content,
			),
			true
		);

		wp_send_json_success( array( 'message' => esc_html__( 'Settings saved.', 'share-social-media' ) ) );
	}

	public static function reset_plugin() {
		if ( ! current_user_can( 'manage_options' ) ) {
			die();
		}

		if ( ! isset( $_POST['reset-plugin'] ) || ! wp_verify_nonce( $_POST['reset-plugin'], 'reset-plugin' ) ) {
			die();
		}

		delete_option( 'stssm_sticky_placement' );
		delete_option( 'stssm_pages_placement' );
		delete_option( 'stssm_posts_placement' );

		wp_send_json_success( array( 'message' => esc_html__( 'The plugin has been reset to its default state.', 'share-social-media' ) ) );
	}
}
